<?php

namespace Drupal\feeds_plupload\Feeds\Fetcher\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\feeds\Plugin\Type\ExternalPluginFormBase;

/**
 * The configuration form for the plupload fetcher.
 */
class PluploadFetcherConfigForm extends ExternalPluginFormBase {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(
    array $form,
    FormStateInterface $form_state
  ) {
    $form['allowed_extensions'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Allowed file extensions'),
      '#description' => $this->t('Allowed file extensions for upload.'),
      '#default_value' => $this->plugin->getConfiguration('allowed_extensions'),
    ];
    $form['autoupload'] = [
      '#type' => 'checkbox',
      '#title' => t('Auto upload'),
      '#description' => t('Start uploading immediately after files are added.'),
      '#default_value' => $this->plugin->getConfiguration('autoupload'),
    ];
    $form['autosubmit'] = [
      '#type' => 'checkbox',
      '#title' => t('Auto submit'),
      '#description' => t('Submit the form after automatic upload has finished.'),
      '#default_value' => $this->plugin->getConfiguration('autosubmit'),
      '#states' => [
        'enabled' => [
          'input[name="autoupload"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(
    array &$form,
    FormStateInterface $form_state
  ) {
    $values = &$form_state->getValues();
    $values['allowed_extensions'] = preg_replace('/\s+/', ' ', trim($values['allowed_extensions']));
  }

}
