<?php

namespace Drupal\feeds_plupload\Feeds\Fetcher;

use Drupal\Component\Serialization\Json;
use Drupal\feeds\Exception\EmptyFeedException;
use Drupal\feeds\FeedInterface;
use Drupal\feeds\Plugin\Type\Fetcher\FetcherInterface;
use Drupal\feeds\Result\FetcherResult;
use Drupal\feeds\StateInterface;
use Drupal\feeds\Plugin\Type\PluginBase;

/**
 * Fetches data using plupload form element.
 *
 * @FeedsFetcher(
 *   id = "plupload",
 *   title = @Translation("File upload with Plupload"),
 *   description = @Translation("Upload content from local files with the plupload widget."),
 *   form = {
 *     "configuration" = "Drupal\feeds_plupload\Feeds\Fetcher\Form\PluploadFetcherConfigForm",
 *     "feed" = "Drupal\feeds_plupload\Feeds\Fetcher\Form\PluploadFetcherFeedForm",
 *   },
 * )
 */
class PluploadFetcher extends PluginBase implements FetcherInterface {

  /**
   * {@inheritdoc}
   */
  public function fetch(FeedInterface $feed, StateInterface $state) {
    if (!isset($state->files)) {
      // Extract files from plupload element.
      $state->files = [];
      foreach (Json::decode($feed->getSource()) as $file) {
        $state->files[] = $file;
      }
      $state->total = count($state->files);
    }

    if ($state->files) {
      $file = array_shift($state->files);
      $state->progress($state->total, $state->total - count($state->files));
      return new FetcherResult($file['tmppath']);
    }

    throw new EmptyFeedException();
  }

  /**
   * {@inheritdoc}
   */
  public function defaultFeedConfiguration() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'allowed_extensions' => 'txt csv tsv xml opml',
      'autoupload' => FALSE,
      'autosubmit' => FALSE,
    ];
  }

}
